# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

import os
import shutil


# Copy over examples and tutorials and all other folders to docs' source
# This makes it so that nbsphinx can properly load the notebook images


def _make_path_dict(source: str, destination: str) -> dict:
    """Function to construct the desired dict structure for the folders to copy."""
    return {"source": source, "destination": destination}


# Set up all paths for source and destination folders.
examples_source = os.path.abspath(
    os.path.join(os.path.dirname(__file__), "..", "examples")
)
examples_dest = os.path.abspath(os.path.join(os.path.dirname(__file__), "examples"))

# Assemble the list of dicts of all source and destination folders to copy.
path_dicts = [
    _make_path_dict(examples_source, examples_dest),
]

# Do the actual copying.
for path_dict in path_dicts:
    source_folder = path_dict["source"]
    dest_folder = path_dict["destination"]
    if os.path.exists(dest_folder):
        shutil.rmtree(dest_folder)
    os.mkdir(dest_folder)

    for root, dirs, files in os.walk(source_folder):
        for dr in dirs:
            os.mkdir(os.path.join(root.replace(source_folder, dest_folder), dr))
        for fil in files:
            if os.path.splitext(fil)[1] in [".ipynb"]:
                source_filename = os.path.join(root, fil)
                dest_filename = source_filename.replace(source_folder, dest_folder)
                shutil.copyfile(source_filename, dest_filename)

# Copy over README.md from root folder.

shutil.copyfile(
    os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "README.txt")),
    os.path.join(os.path.dirname(__file__), "README.txt"),
)

# -- Project information -----------------------------------------------------

project = "GUM2DFT"
copyright = "2021, Sascha Eichstädt, Björn Ludwig (PTB)"
author = "Sascha Eichstädt, Björn Ludwig"

# The full version, including alpha/beta/rc tags
release = "0.0.96"
version = release


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones. We use rst2pdf to generate the pdf without LaTeX and nbsphinx to convert our
# example notebooks to HTML documentation.
extensions = ["rst2pdf.pdfbuilder", "nbsphinx"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
# source_suffix = ['.rst', '.md']
source_suffix = [".rst", ".txt"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build"]

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "alabaster"

# -- Options for PDF output -------------------------------------------------
# These were taken from https://gist.github.com/alfredodeza/7fb5c667addb1c6963b9

# Create a compressed PDF
# Use true/false (lower case) or 1/0
# compressed = True

# Add a blank page at the beginning of the document
blank_first_page = False

# index - master document
# rst2pdf - name of the generated pdf
# Sample rst2pdf doc - title of the pdf
# Your Name - author name in the pdf
pdf_documents = [
    ("index", "GUM2DFT", "GUM2DFT documentation", u"Sascha Eichstädt, Björn Ludwig"),
]

# A comma-separated list of custom stylesheets. Example:
pdf_stylesheets = ["sphinx", "a4"]

supress_warnings = ["ref.citation"]

latex_elements = {
    "classoptions": "oneside,openany",
}
